@@ -52,7 +52,7 @@ setMethod(
 
 if (!isGeneric(".parseElems")) {
   setGeneric(".parseElems", function(object, objects,
-                                     compareRasterFileLength = 1e6,
+                                     length = 1e6,
                                      algo = "xxhash64") {
     standardGeneric(".parseElems")
   })
