@@ -1,10 +1,10 @@
 path <- system.file("sampleModules", package = "SpaDES.core")
 sampleModules <- dir(path)
-x <- moduleMetadata(sampleModules[3], path)
+x <- moduleMetadata(sampleModules[3], path = path)
 
 # using simList
 mySim <- simInit(
-   times = list(start = 2000.0, end = 2002.0, timeunit = "year"),
+   times = list(start = 2000.0, end = 2001.0, timeunit = "year"),
    params = list(
      .globals = list(stackName = "landscape")
    ),
